==> open-xchange-core_7.6.1.orig.tar.bz2: open-xchange-core-7.6.1/com.openexchange.server/src/com/openexchange/groupware/settings/tree/modules/mail/MsgFormat.java <==
/*
 *
 *    OPEN-XCHANGE legal information
 *
 *    All intellectual property rights in the Software are protected by
 *    international copyright laws.
 *
 *
 *    In some countries OX, OX Open-Xchange, open xchange and OXtender
 *    as well as the corresponding Logos OX Open-Xchange and OX are registered
 *    trademarks of the Open-Xchange, Inc. group of companies.
 *    The use of the Logos is not covered by the GNU General Public License.
 *    Instead, you are allowed to use these Logos according to the terms and
 *    conditions of the Creative Commons License, Version 2.5, Attribution,
 *    Non-commercial, ShareAlike, and the interpretation of the term
 *    Non-commercial applicable to the aforementioned license is published
 *    on the web site http://www.open-xchange.com/EN/legal/index.html.
 *
 *    Please make sure that third-party modules and libraries are used
 *    according to their respective licenses.
 *
 *    Any modifications to this package must retain all copyright notices
 *    of the original copyright holder(s) for the original code used.
 *
 *    After any such modifications, the original and derivative code shall remain
 *    under the copyright of the copyright holder(s) and/or original author(s)per
 *    the Attribution and Assignment Agreement that can be located at
 *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
 *    given Attribution for the derivative code and a license granting use.
 *
 *     Copyright (C) 2004-2014 Open-Xchange, Inc.
 *     Mail: info@open-xchange.com
 *
 *
 *     This program is free software; you can redistribute it and/or modify it
 *     under the terms of the GNU General Public License, Version 2 as published
 *     by the Free Software Foundation.
 *
 *     This program is distributed in the hope that it will be useful, but
 *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
 *     for more details.
 *
 *     You should have received a copy of the GNU General Public License along
 *     with this program; if not, write to the Free Software Foundation, Inc., 59
 *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

package com.openexchange.groupware.settings.tree.modules.mail;

import com.openexchange.exception.OXException;
import com.openexchange.groupware.contexts.Context;
import com.openexchange.groupware.ldap.User;
import com.openexchange.groupware.settings.IValueHandler;
import com.openexchange.groupware.settings.PreferencesItemService;
import com.openexchange.groupware.settings.Setting;
import com.openexchange.groupware.settings.SettingExceptionCodes;
import com.openexchange.groupware.userconfiguration.UserConfiguration;
import com.openexchange.mail.usersetting.UserSettingMail;
import com.openexchange.mail.usersetting.UserSettingMailStorage;
import com.openexchange.session.Session;

/**
 *
 * @author <a href="mailto:marcus@open-xchange.org">Marcus Klein</a>
 */
public class MsgFormat implements PreferencesItemService {

    /**
     * Default constructor.
     */
    public MsgFormat() {
        super();
    }

    /**
     * {@inheritDoc}
     */
    @Override
    public String[] getPath() {
        return new String[] { "modules", "mail", "msgformat" };
    }

    /**
     * {@inheritDoc}
     */
    @Override
    public IValueHandler getSharedValue() {
        return new IValueHandler() {

            @Override
            public void getValue(final Session session, final Context ctx, final User user, final UserConfiguration userConfig, final Setting setting) throws OXException {
                final UserSettingMail settings = UserSettingMailStorage.getInstance().getUserSettingMail(user.getId(), ctx);
                if (null != settings) {
                    // html vs. text vs. alternative
                    String format = "html";
                    {
                        int msgFormat = settings.getMsgFormat();
                        if (UserSettingMail.MSG_FORMAT_TEXT_ONLY == msgFormat) {
                            format = "text";
                        } else if (UserSettingMail.MSG_FORMAT_HTML_ONLY == msgFormat) {
                            format = "html";
                        } else if (UserSettingMail.MSG_FORMAT_BOTH == msgFormat) {
                            format = "alternative";
                        }
                    }
                    setting.setSingleValue(format);
                }
            }

            @Override
            public boolean isAvailable(final UserConfiguration userConfig) {
                return userConfig.hasWebMail();
            }

            @Override
            public boolean isWritable() {
                return true;
            }

            @Override
            public void writeValue(final Session session, final Context ctx, final User user, final Setting setting) throws OXException {
                final UserSettingMailStorage storage = UserSettingMailStorage.getInstance();
                final UserSettingMail usm = storage.getUserSettingMail(user.getId(), ctx);
                if (null != usm) {
                    int msgFormat = UserSettingMail.MSG_FORMAT_HTML_ONLY;
                    {
                        final String s = setting.getSingleValue().toString();
                        if (com.openexchange.java.Strings.isEmpty(s)) {
                            return;
                        }
                        if ("text".equalsIgnoreCase(s)) {
                            msgFormat = UserSettingMail.MSG_FORMAT_TEXT_ONLY;
                        } else if ("html".equalsIgnoreCase(s)) {
                            msgFormat = UserSettingMail.MSG_FORMAT_HTML_ONLY;
                        } else if ("alternative".equalsIgnoreCase(s)) {
                            msgFormat = UserSettingMail.MSG_FORMAT_BOTH;
                        }
                    }

                    try {
                        if (msgFormat != usm.getMsgFormat()) {
                            usm.setMsgFormat(msgFormat);
                            storage.saveUserSettingMail(usm, user.getId(), ctx);
                        }
                    } catch (final NumberFormatException e) {
                        throw SettingExceptionCodes.JSON_READ_ERROR.create(e);
                    }
                }
            }

            @Override
            public int getId() {
                return -1;
            }
        };
    }
}

==> open-xchange-core_7.8.2.orig.tar.bz2: open-xchange-core-7.8.2/com.openexchange.server/src/com/openexchange/groupware/settings/tree/modules/mail/MsgFormat.java <==
/*
 *
 *    OPEN-XCHANGE legal information
 *
 *    All intellectual property rights in the Software are protected by
 *    international copyright laws.
 *
 *
 *    In some countries OX, OX Open-Xchange, open xchange and OXtender
 *    as well as the corresponding Logos OX Open-Xchange and OX are registered
 *    trademarks of the OX Software GmbH group of companies.
 *    The use of the Logos is not covered by the GNU General Public License.
 *    Instead, you are allowed to use these Logos according to the terms and
 *    conditions of the Creative Commons License, Version 2.5, Attribution,
 *    Non-commercial, ShareAlike, and the interpretation of the term
 *    Non-commercial applicable to the aforementioned license is published
 *    on the web site http://www.open-xchange.com/EN/legal/index.html.
 *
 *    Please make sure that third-party modules and libraries are used
 *    according to their respective licenses.
 *
 *    Any modifications to this package must retain all copyright notices
 *    of the original copyright holder(s) for the original code used.
 *
 *    After any such modifications, the original and derivative code shall remain
 *    under the copyright of the copyright holder(s) and/or original author(s)per
 *    the Attribution and Assignment Agreement that can be located at
 *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
 *    given Attribution for the derivative code and a license granting use.
 *
 *     Copyright (C) 2016-2020 OX Software GmbH
 *     Mail: info@open-xchange.com
 *
 *
 *     This program is free software; you can redistribute it and/or modify it
 *     under the terms of the GNU General Public License, Version 2 as published
 *     by the Free Software Foundation.
 *
 *     This program is distributed in the hope that it will be useful, but
 *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
 *     for more details.
 *
 *     You should have received a copy of the GNU General Public License along
 *     with this program; if not, write to the Free Software Foundation, Inc., 59
 *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

package com.openexchange.groupware.settings.tree.modules.mail;

import com.openexchange.exception.OXException;
import com.openexchange.groupware.contexts.Context;
import com.openexchange.groupware.ldap.User;
import com.openexchange.groupware.settings.IValueHandler;
import com.openexchange.groupware.settings.PreferencesItemService;
import com.openexchange.groupware.settings.Setting;
import com.openexchange.groupware.settings.SettingExceptionCodes;
import com.openexchange.groupware.userconfiguration.UserConfiguration;
import com.openexchange.mail.usersetting.UserSettingMail;
import com.openexchange.mail.usersetting.UserSettingMailStorage;
import com.openexchange.session.Session;

/**
 *
 * @author <a href="mailto:marcus@open-xchange.org">Marcus Klein</a>
 */
public class MsgFormat implements PreferencesItemService {

    /**
     * Default constructor.
     */
    public MsgFormat() {
        super();
    }

    /**
     * {@inheritDoc}
     */
    @Override
    public String[] getPath() {
        return new String[] { "modules", "mail", "msgformat" };
    }

    /**
     * {@inheritDoc}
     */
    @Override
    public IValueHandler getSharedValue() {
        return new IValueHandler() {

            @Override
            public void getValue(final Session session, final Context ctx, final User user, final UserConfiguration userConfig, final Setting setting) throws OXException {
                final UserSettingMail settings = UserSettingMailStorage.getInstance().getUserSettingMail(user.getId(), ctx);
                if (null != settings) {
                    // html vs. text vs. alternative
                    String format = "html";
                    {
                        int msgFormat = settings.getMsgFormat();
                        switch (msgFormat) {
                            case UserSettingMail.MSG_FORMAT_TEXT_ONLY:
                                format = "text";
                                break;
                            case UserSettingMail.MSG_FORMAT_HTML_ONLY:
                                format = "html";
                                break;
                            case UserSettingMail.MSG_FORMAT_BOTH:
                                format = "alternative";
                                break;
                        }
                    }
                    setting.setSingleValue(format);
                }
            }

            @Override
            public boolean isAvailable(final UserConfiguration userConfig) {
                return userConfig.hasWebMail();
            }

            @Override
            public boolean isWritable() {
                return true;
            }

            @Override
            public void writeValue(final Session session, final Context ctx, final User user, final Setting setting) throws OXException {
                final UserSettingMailStorage storage = UserSettingMailStorage.getInstance();
                final UserSettingMail usm = storage.getUserSettingMail(user.getId(), ctx);
                if (null != usm) {
                    int msgFormat = UserSettingMail.MSG_FORMAT_HTML_ONLY;
                    {
                        final String s = setting.getSingleValue().toString();
                        if (com.openexchange.java.Strings.isEmpty(s)) {
                            return;
                        }
                        if ("text".equalsIgnoreCase(s)) {
                            msgFormat = UserSettingMail.MSG_FORMAT_TEXT_ONLY;
                        } else if ("html".equalsIgnoreCase(s)) {
                            msgFormat = UserSettingMail.MSG_FORMAT_HTML_ONLY;
                        } else if ("alternative".equalsIgnoreCase(s)) {
                            msgFormat = UserSettingMail.MSG_FORMAT_BOTH;
                        }
                    }

                    try {
                        if (msgFormat != usm.getMsgFormat()) {
                            usm.setMsgFormat(msgFormat);
                            storage.saveUserSettingMail(usm, user.getId(), ctx);
                        }
                    } catch (final NumberFormatException e) {
                        throw SettingExceptionCodes.JSON_READ_ERROR.create(e);
                    }
                }
            }

            @Override
            public int getId() {
                return -1;
            }
        };
    }
}
